Name:           kitty
Version:        0.14.2
Release:        1%{?dist}
Summary:        A cross-platform, fast, feature full, GPU based terminal emulator

License:        GPLv3
URL:            https://sw.kovidgoyal.net/kitty/
Source0:        https://github.com/kovidgoyal/kitty/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  dbus-devel
BuildRequires:  libXcursor-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libXi-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libxkbcommon-x11-devel
BuildRequires:  python3-devel
BuildRequires:  wayland-devel
BuildRequires:  wayland-protocols-devel
BuildRequires:  zlib
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  desktop-file-utils
BuildRequires:  python3-sphinx

Requires:       python3
Requires:       harfbuzz
Requires:       freetype
Requires:       fontconfig
#Terminfo file has been split from the main programme and is requied for use without errors
#It has been seperated to support SSH into remote machines using kitty as per the maintainers suggestion
#Install the terminfo file on the remote machine, it is available on the same COPR repo as this file
Requires:       kitty-terminfo
#Very weak dependancies, these are required to enable all features of kitty's "kittens" functions
#install separately
Suggests:       ImageMagick
Suggests:       python3-pygments

%description
Kitty is a fast, feature full, GPU based terminal emulator.
-Offloads rendering to the GPU for lower system load and buttery smooth
 scrolling. Uses threaded rendering to minimize input latency.
-Supports all modern terminal features: graphics (images), Unicode, true-color,
 OpenType ligatures, mouse protocol, focus tracking, bracketed paste and
 several new terminal protocol extensions.
-Supports tiling multiple terminal windows side by side in different layouts
 without needing to use an extra program like tmux.
-Can be controlled from scripts or the shell prompt, even over SSH.
-Has a framework for Kittens, small terminal programs that can be used to
 extend kitty's functionality. For example, they are used for Unicode input,
 Hints and Side-by-side diff.
-Supports start-up sessions which allow you to specify the window/tab layout,
 working directories and programs to run on start-up.
-Cross-platform: kitty works on Linux and mac OS, but because it uses only
 OpenGL for rendering, it should be trivial to port to other Unix-like
 platforms.
-Allows you to open the scroll-back buffer in a separate window using arbitrary
 programs of your choice. This is useful for browsing the history comfortably
 in a pager or editor.


%package terminfo
Summary:        The terminfo file for Kitty Terminal
BuildArch:      noarch

%description terminfo
Kitty is a fast, feature full, GPU based terminal emulator.
-Offloads rendering to the GPU for lower system load and buttery smooth
 scrolling. Uses threaded rendering to minimize input latency.
-Supports all modern terminal features: graphics (images), Unicode, true-color,
 OpenType ligatures, mouse protocol, focus tracking, bracketed paste and
 several new terminal protocol extensions.
-Supports tiling multiple terminal windows side by side in different layouts
 without needing to use an extra program like tmux.
-Can be controlled from scripts or the shell prompt, even over SSH.
-Has a framework for Kittens, small terminal programs that can be used to
 extend kitty's functionality. For example, they are used for Unicode input,
 Hints and Side-by-side diff.
-Supports start-up sessions which allow you to specify the window/tab layout,
 working directories and programs to run on start-up.
-Cross-platform: kitty works on Linux and mac OS, but because it uses only
 OpenGL for rendering, it should be trivial to port to other Unix-like
 platforms.
-Allows you to open the scroll-back buffer in a separate window using arbitrary
 programs of your choice. This is useful for browsing the history comfortably
 in a pager or editor.


%prep
%autosetup -n %{name}-%{version}

#replace python shebangs to make them compatible with fedora
sed -i -e 's/env python3/python3/' ./*.py
sed -i -e 's/env python3/python3/' ./*/*.py
sed -i -e 's/env python3/python3/' ./*/*/*.py
sed -i -e 's/env python/python3/' ./*.py
sed -i -e 's/env python/python3/' ./*/*.py
sed -i -e 's/env python/python3/' ./*/*/*.py
sed -i -e 's/env python3/python3/' ./kitty/launcher/kitty


%build
%{__python3} setup.py build


%install
rm -rf $RPM_BUILD_ROOT
%{__python3} setup.py linux-package --libdir-name=%{_lib} --prefix=%{buildroot}%{_prefix} --update-check-interval=0 --debug

#rpmlint complains about these two files, so remove them
#rm %{buildroot}%{_datadir}/doc/kitty/html/.buildinfo
#rm %{buildroot}%{_datadir}/doc/kitty/html/.nojekyll


%check
%{__python3} setup.py test --prefix=%{buildroot}%{_prefix}
desktop-file-validate %{buildroot}/%{_datadir}/applications/kitty.desktop
 

%files
%license LICENSE
%{_mandir}/man1/kitty.1.*
%{_bindir}/kitty
%{_libdir}/%{name}/*
%{_datadir}/applications/kitty.desktop
%{_datadir}/icons/hicolor/256x256/apps/kitty.png
%{_datadir}/doc/kitty/html/


%files terminfo
%license LICENSE
%{_datadir}/terminfo/x/xterm-kitty


%changelog
* Fri Jul 12 2019 eskse <eskse@users.noreply.github.com> 0.14.2-1
- Initial version of file
